# COST03-BP05: Configure billing and cost management tools

## Description

Set up cost management tooling.

## Implementation Guidance

- Enable native cost tools
- Configure third-party tools if needed
- Set up dashboards
- Automate cost reports
- Integrate with alerting

## Risk Level

Low - Manual tracking is inefficient.

## Related Best Practices

- [COST03-BP01](COST03-BP01-Cost-Effective-Resources.md)
- [COST01-BP06](../COST01-Practice-Cloud-Financial-Management/COST01-BP06-Monitor-Cost.md)
